@@ -16,6 +16,9 @@ THEME_TUW_MATOMO_URL = "https://s191.dl.hpc.tuwien.ac.at/"
 THEME_TUW_DISPLAY_STAGING_WARNING = False
 """Whether or not to display a warning that it's the staging system."""
 
+THEME_TUW_CONTACT_EMAIL = "tudata@tuwien.ac.at"
+"""The e-mail address provided as contact."""
+
 APP_THEME = ["semantic-ui"]
 
 
@@ -26,8 +29,8 @@ APP_THEME = ["semantic-ui"]
 # Name displayed in tab
 THEME_SITENAME = "TU Data Repository"
 
-# Frontpage
-THEME_FRONTPAGE = True
+# Enabling the frontpage would collide with our custom view function
+THEME_FRONTPAGE = False
 
 # Templates
 BASE_TEMPLATE = "invenio_theme_tuw/page.html"
