@@ -24,22 +24,20 @@ class InvenioThemeTUW:
         self.init_config(app)
         app.extensions["invenio-theme-tuw"] = self
 
-        # since invenio-app-rdm currently (april 2021) doesn't offer an easy way of
-        # overriding the provided jinja templates, we have to perform a workaround:
-        # the first blueprint that has a definition for a template (per name) gets
-        # selected by 'render_template'
-        # thus, we just have to make sure that our blueprint is inserted before the
-        # 'invenio_app_rdm' blueprints
-        # note: the below code requires Flask 2.0.2+
         blueprint = create_blueprint(app)
         app.register_blueprint(blueprint)
 
-        blueprints = {"invenio_theme_tuw": blueprint}
-        for name, blueprint in app.blueprints.items():
-            if name != "invenio_theme_tuw":
-                blueprints[name] = blueprint
-
-        app.blueprints = blueprints
+        @app.before_first_request
+        def register_bp_first():
+            # since invenio-app-rdm currently (april 2021) doesn't offer an easy way of
+            # overriding the provided jinja templates, we have to perform a workaround:
+            # the first blueprint that has a definition for a template (per name) gets
+            # selected by 'render_template'
+            # thus, we just have to make sure that our blueprint is inserted before the
+            # 'invenio_app_rdm' blueprints
+            # note: the below code requires Flask 2.0.2+ and Python 3.7+
+            bps = {name: bp for name, bp in app.blueprints.items() if name != "invenio_theme_tuw"}
+            app.blueprints = {"invenio_theme_tuw": blueprint, **bps}
 
     def init_config(self, app):
         """Initialize configuration."""
